diff plugin/PluginXml.h @ 314:70a232b1f12a

* Make XmlExportable::toXml the function that is universally overridden (and pure virtual) instead of toXmlString. Tidies up some classes, notably the model classes, significantly. Closes #1794561.
author Chris Cannam
date Thu, 18 Oct 2007 10:15:07 +0000
parents f277a171749d
children 4c000e196bf1
line wrap: on
line diff
--- a/plugin/PluginXml.h	Wed Oct 17 12:58:45 2007 +0000
+++ b/plugin/PluginXml.h	Thu Oct 18 10:15:07 2007 +0000
@@ -31,19 +31,20 @@
     /**
      * Export plugin settings to XML.
      */
-    virtual QString toXmlString(QString indent = "",
-                                QString extraAttributes = "") const;
+    virtual void toXml(QTextStream &stream,
+                       QString indent = "",
+                       QString extraAttributes = "") const;
 
     /**
      * Set the parameters and program of a plugin from a set of XML
      * attributes.  This is a partial inverse of toXmlString.
      */
     virtual void setParameters(const QXmlAttributes &);
 
     /**
      * Set the parameters and program of a plugin from an XML plugin
      * element as returned by toXmlString.  This is a partial inverse
      * of toXmlString.
      */
     virtual void setParametersFromXml(QString xml);
@@ -31,19 +31,20 @@
     /**
      * Set the parameters and program of a plugin from a set of XML
-     * attributes.  This is a partial inverse of toXmlString.
+     * attributes.  This is a partial inverse of toXml.
      */
     virtual void setParameters(const QXmlAttributes &);
@@ -31,19 +31,20 @@
     /**
      * Set the parameters and program of a plugin from an XML plugin
-     * element as returned by toXmlString.  This is a partial inverse
-     * of toXmlString.
+     * element as returned by toXml.  This is a partial inverse of
+     * toXml.
      */
     virtual void setParametersFromXml(QString xml);